<img src="https://gwpy.github.io/images/gwpy_1200.png" alt="GWpy logo" width="400" />

[![PyPI version](https://badge.fury.io/py/gwpy.svg)](http://badge.fury.io/py/gwpy) 
[![DOI](https://zenodo.org/badge/9979119.svg)](https://zenodo.org/badge/latestdoi/9979119) 

[![Build Status](https://travis-ci.org/gwpy/gwpy.svg?branch=master)](https://travis-ci.org/gwpy/gwpy) 
[![Coverage Status](https://coveralls.io/repos/gwpy/gwpy/badge.svg)](https://coveralls.io/r/gwpy/gwpy) 
[![Research software impact](http://depsy.org/api/package/pypi/gwpy/badge.svg)](http://depsy.org/package/python/gwpy) 
[![Code Climate](https://codeclimate.com/github/gwpy/gwpy/badges/gpa.svg)](https://codeclimate.com/github/gwpy/gwpy) 
[![Code Health](https://landscape.io/github/gwpy/gwpy/master/landscape.svg?style=flat)](https://landscape.io/github/gwpy/gwpy/master) 

[https://gwpy.github.io](https://gwpy.github.io)

GWpy is a collaboration-driven Python package providing tools for studying data from ground-based gravitational-wave detectors.

GWpy provides a user-friendly, intuitive interface to the common time-domain and frequency-domain data produced by the LIGO and Virgo instruments and their analysis, with easy-to-follow tutorials at each step.
